"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DailyRewards = void 0;
const request_1 = require("../utils/request");
class DailyRewards {
    /**
       *
       * @description Get the daily rewards details
       * @param {string} language The language to set
       * @param {string} cookie The cookie to set
       * @param {string | number} day get the day's rewards
       *
       */
    async getDayReward(language, cookie, day) {
        var _a;
        const instance = (0, request_1.request)("dailyrewards");
        (0, request_1.setLanguage)(language);
        const res = await instance.get("/home", {
            headers: {
                "Cookie": cookie,
            },
            params: {
                "lang": language,
                "act_id": "e202102251931481",
            },
        });
        const todayDate = new Date().toLocaleDateString("en-US", {
            timeZone: "Asia/Hong_Kong",
        });
        let queryDay = Number(day);
        if (typeof day === "string") {
            queryDay = parseInt(day, 10);
        }
        if (!queryDay) {
            queryDay = new Date(todayDate).getDate();
        }
        if (((_a = res.data) === null || _a === void 0 ? void 0 : _a.retcode) === 0) {
            const { data } = res;
            return data.data.awards[queryDay - 1];
        }
        throw new Error(res.data.retcode);
    }
    /**
     *
     * @description Claim the daily rewards
     * @param {string} language The language to set
     * @param {string} cookie The cookie to set
     */
    async claimDailyReward(language, cookie) {
        var _a, _b, _c, _d;
        const instance = (0, request_1.request)("dailyrewards");
        const res = await instance.post("/sign", {
            "act_id": "e202102251931481",
        }, {
            headers: {
                "Cookie": cookie,
                "Content-Type": "application/json",
                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36",
            },
            params: {
                "lang": language,
            },
        });
        if (((_a = res.data) === null || _a === void 0 ? void 0 : _a.retcode) === -100) {
            return {
                status: "Invalid cookie",
            };
        }
        if (((_b = res.data) === null || _b === void 0 ? void 0 : _b.retcode) === -5003) {
            return {
                status: "Already claimed",
            };
        }
        if (((_c = res.data) === null || _c === void 0 ? void 0 : _c.data.code) === "ok" && ((_d = res.data) === null || _d === void 0 ? void 0 : _d.data.retcode) === 0) {
            console;
            return {
                status: "success",
            };
        }
        throw new Error(res.data.retcode);
    }
}
exports.DailyRewards = DailyRewards;
//# sourceMappingURL=dailyReward.js.map